
import * as THREE from 'three';
import { useThree, useLoader } from '@react-three/fiber';

import { SceneHandler } from './sceneHandlerV2';
import { useEffect } from 'react';

export function BackgroundMesh({ imageSize, imageURL ,sceneHandler , sceneObj }) {
    const texture = useLoader(THREE.TextureLoader, imageURL);
    const imageWidth = sceneHandler.imageSize.x;
    const imageHeight = sceneHandler.imageSize.y;
    const imageResolution = sceneHandler.imageResolution;
    const actualImageSize = new THREE.Vector2(imageWidth / imageResolution, imageHeight / imageResolution);
    
    const three = useThree();
    useEffect(() => {
      sceneHandler.setupScene(three);
      if(sceneObj && sceneObj.bgImage)
      {
        sceneHandler.addModels(sceneObj.finalVectorArray)
      }
      return ()=>
      {
        sceneHandler.removeModelList();
      }
  }, []);
    
    
    
    return (
      <>
        <mesh name='bg' >
          <planeGeometry args={[actualImageSize.x, actualImageSize.y]} />
          <meshBasicMaterial map={texture} />
        </mesh>

        <mesh name='shadowPlane'  rotation={[-1.07,0,0]} scale={[ 0.8 , 0.5,1]} position={[0,-1.2913098317295773,0.6473203737076866]} receiveShadow={true}>
          <planeGeometry args={[5,2]} />
          <shadowMaterial side={2} opacity={0.35} />
        </mesh>

        <directionalLight intensity={0.2} color={0xffffff} position={[0, 3, -2]} castShadow={true}   />
      </>
    );
  }