// ThreeScene.js
import React, { forwardRef, useEffect, Suspense, useState, useRef, memo, useMemo } from 'react';
import { useDispatch } from 'react-redux';
import { Canvas } from '@react-three/fiber';
import { Environment } from '@react-three/drei';
import { BackgroundMesh } from './BackgroundMesh';
import * as THREE from 'three';
import { SceneHandler } from './sceneHandlerV2';
import { setSceneHandler } from '@store/actions/saved-scene-actions';
// import { modalObj } from '@services/shades-module';
// import hdri from '../assets/hdris/dancing_hall_1k.hdr'

import '../css/style.css'

const ThreeScene = memo(forwardRef((props, ref) => {
  const { sceneObj, sampleRoomImage, productImage, onFullScreen , index, callback, hideOptions=false, width, height } = props;
  const dispatch = useDispatch();
  const sceneHandlerRef = useRef(null);
  const sceneHandler = useMemo(() => new SceneHandler(), []);
  if(width && height) {
    sceneHandler.imageSize = { x: width, y: height };
    sceneHandler.imageHalfWidth = sceneHandler.imageSize.x / 2;
    sceneHandler.imageHalfHeight = sceneHandler.imageSize.y / 2;
  }

  sceneHandler.currentRoomImage = sceneObj ? sceneObj.bgImage : sampleRoomImage;
  sceneHandler.currentBlindModel = sceneObj ? sceneObj.currentModel : productImage?.ar_model_url;
  const setReduxSceneHandler = (handler) => {
    dispatch(setSceneHandler(handler));
  };

  const [imgOptions, setImgOptions] = useState({});
  const isLoaded = useRef(true);
 
  useEffect(()=>{
    callback && callback(index, sceneHandler);
}, [index, callback]);

  useEffect(() => {
    sceneHandlerRef.current = sceneHandler;
    setReduxSceneHandler(sceneHandler); // Update scene handler in Redux store
  }, [sceneHandler]);



  useEffect(() => {
    if (isLoaded.current) {
      if (!sceneObj) {
        if (sceneHandler.modelsList.children.length === 0) {
          sceneHandler.fetchData(sceneHandler.currentRoomImage);
        }
      }
      isLoaded.current = false;
    }
  }, [productImage, sceneHandler, sceneObj]);

  sceneHandler.addEventListener('uiOptions', (data) => {
    if(!hideOptions) {
      setImgOptions(data);
    }
  });


  return (
    <>
      <div className='canvas-wrapper'>
        <Canvas shadows camera={{ near: 0.1, far: 1000, position: [0, 0, 3] }}>
          <Suspense>
            <BackgroundMesh
              imageURL={sceneHandler.currentRoomImage}
              sceneHandler={sceneHandler}
              sceneObj={sceneObj}
            />
          </Suspense>
          {/* <Environment files={hdri} blur={1} /> */}
        </Canvas>
      </div>
      
      {imgOptions?.data && (
        <div className='blind-controls '>
          <div className='blind-container'>
            {imgOptions?.data?.open && (
              <button
                className=' btn-transparent'
                onClick={() => {
                  
                  sceneHandler.playAnimation('open', true)}}
              >
                <img
                  alt=''
                  src='https://visualization.graberblinds.com/assets/graphics/window-control-horizontal-open.svg'
                />
              </button>
            )}

            {imgOptions?.data?.close && (
              <button
                className=' btn-transparent'
                onClick={() => sceneHandler.playAnimation('open', false)}
              >
                <img
                  alt=''
                  src='https://visualization.graberblinds.com/assets/graphics/window-control-horizontal-close.svg'
                />
              </button>
            )}

            {imgOptions?.data?.foldIn && (
              <button
                className=' btn-transparent'
                onClick={() => sceneHandler.playAnimation('fold', true)}
              >
                <img
                  alt=''
                  src='https://visualization.graberblinds.com/assets/graphics/window-control-horizontal-tilt-open.svg'
                />
              </button>
            )}

            {imgOptions?.data?.foldOut && (
              <button className=' btn-transparent' onClick={() => sceneHandler.playAnimation('fold', false)}  >
                <img alt='' src='https://visualization.graberblinds.com/assets/graphics/window-control-horizontal-tilt-close.svg' />
              </button>
            )}

           { productImage?.product_name === 'Draperies' && 
           <>
           <button className=' btn-transparent' onClick={() => sceneHandler.scaleXAxis(true)}             >
              <img alt='' src='https://visualization.graberblinds.com/assets/graphics/window-extend-wider.svg' />
            </button>

            <button className=' btn-transparent' onClick={() => sceneHandler.scaleXAxis(false)} >
              <img alt='' src='https://visualization.graberblinds.com/assets/graphics/window-extend-narrower.svg' />
            </button>

            <button className=' btn-transparent' onClick={() => sceneHandler.scaleNegativeYAxis(true)} >
              <img  alt='' src='https://visualization.graberblinds.com/assets/graphics/window-extend-higher.svg' />
            </button>

            <button className=' btn-transparent' onClick={() => sceneHandler.scaleNegativeYAxis(false)} >
              <img alt='' src='https://visualization.graberblinds.com/assets/graphics/window-extend-lower.svg' />
            </button>
            </>
            }

          </div>

          [<div className='blind-container m-l-10'>
            <button
              className=' btn-transparent'
              onClick={() => sceneHandler.resetZoom()}
            >
              <img
                alt=''
                src='https://visualization.graberblinds.com/assets/graphics/2021_zoom_reset.svg'
              />
            </button>

            <button
              className=' btn-transparent'
              onClick={() => sceneHandler.zoom(false)}
            >
              <img
                alt=''
                src='https://visualization.graberblinds.com/assets/graphics/2021_zoom_out.svg'
              />
            </button>
            <button
              className=' btn-transparent'
              onClick={() => sceneHandler.zoom(true)}
            >
              <img
                alt=''
                src='https://visualization.graberblinds.com/assets/graphics/2021_zoom_in.svg'
              />
            </button>

            <button className=' btn-transparent full-screen' onClick={onFullScreen}>
              <img
                alt=''
                src='https://visualization.graberblinds.com/assets/graphics/2021_fullscreen.svg'
              />
            </button>
          </div>]
        </div>
      )}
    </>
  );
}));

export default ThreeScene;
