import React from 'react';
import { useSelector } from 'react-redux';
import { capitalCase } from "@services/shared";

import './info.scss';

const Info = () => {
    const sampleRoomDetails = useSelector((state) => state.savedProjects.sampleRoom);
    const defaultProduct = useSelector((state) => state.savedProjects.defaultProduct);
    const itemsNotToDisplay = [
        "createdAt", "curtain_image_name", "curtain_image_path", "openingOption",
        "product_image_name", "product_image_path", "status", "updatedAt", "id",
        "shades/Window", 'ar_model_name', 'ar_model_url'
    ];

    let itemArray = {};
    for(let x in defaultProduct){
        itemsNotToDisplay.includes(x) ? delete defaultProduct.x : itemArray[x] = defaultProduct[x]
    }

    const { color: colors, product_name: productName, ...optionsData } = { ...itemArray }
    const windowSize = sampleRoomDetails.window_estimate_size.split(',');
    
    return(
        <div className='info-container'>
            <div className="table-aside">
                <table className="table table-striped">
                    <tbody>
                    <tr>
                        <td>Product Model </td>
                        <td>{productName ?? ''}</td>
                    </tr>
                    {
                        colors && (colors?.color_name !== (null || undefined)) ?
                        (
                            <tr>
                                <td>Color</td>
                                <td>{colors?.color_name ?? ''}</td>
                            </tr>

                        ) : <></>
                    }

                    {
                        colors && (colors?.color_number !== (null || undefined)) ? (
                            <>
                                <tr>
                                    <td>Color Number</td>
                                    <td>{ colors?.color_number ?? ''}</td>
                                </tr>
                            </>
                        ): 
                        <></>
                    }
                    {
                        colors && (colors?.color_style !== (null || undefined)) ? (
                            <>
                                <tr>
                                    <td>Style</td>
                                    <td>{colors?.color_style ?? ''}</td>
                                </tr>
                            </>
                        ): 
                        <></>
                    }

                    {
                        optionsData &&
                        Object.keys(optionsData)?.map((item, key) => 
                            (
                                <tr key={key}>
                                    <td>{capitalCase(item)}</td>
                                    <td>{Object.values(optionsData)?.[key] ?? ''}</td>
                                </tr>
                            )
                        )
                    }
                    
                    <tr>
                        <td>Estimated Window Sizes</td>
                        <td>{windowSize[0]}</td>
                    </tr>
                    <tr>
                        <td></td>
                        <td>{windowSize[1]}</td>
                    </tr>
                    <tr>
                        <td></td>
                        <td>{windowSize[2]}</td>
                    </tr>
                    </tbody>
                </table>
            </div>
        </div>
    )
}

export default Info;